/**
 * Copyright (c) 2021 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */
#include "pokergameassets.h"

bool pokerGameAssetsInit(pokergameassets_t *assets) {
  uint8_t i;
  assetManagerInit(&assets->manager);

  // Initialize the language buffer.
  languageInit(&assets->language, "locale/language/en-US.csv");

  
  assetManagerShaderLoad(&assets->manager, &assets->shader,
    "shaders/textured.vert", "shaders/textured.frag"
  );

  assetManagerLoadFont(&assets->manager, &assets->font,
    "fonts/opensans/OpenSans-Bold.ttf"
  );

  // Load the world textures.
  assetManagerLoadTexture(&assets->manager, &assets->testTexture,
    "textures/test_texture.png"
  );
  assetManagerLoadTexture(&assets->manager, &assets->cardTexture,
    "poker/cards.png"
  );
  assetManagerLoadTexture(&assets->manager, &assets->roomTexture,
    "poker/pub_skywall.png"
  );

  // Load character textures.
  for(i = 0; i < POKER_CHARACTER_DEFINITIONS_COUNT; i++) {
    assetManagerLoadTexture(&assets->manager, assets->characterTextures + i,
      POKER_CHARACTER_DEFINITIONS[i].fileTexture
    );
  }

  return true;
}

void pokerGameAssetsDispose(pokergameassets_t *assets) {
  // Now we unload in what is essentially the reverse of the above.
  textureDispose(&assets->roomTexture);
  textureDispose(&assets->testTexture);
  textureDispose(&assets->cardTexture);
  fontDispose(&assets->font);
  shaderDispose(&assets->shader);
  languageDispose(&assets->language);
}